
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "source/auto_examples/plot_asos_temp.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        Click :ref:`here <sphx_glr_download_source_auto_examples_plot_asos_temp.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_source_auto_examples_plot_asos_temp.py:


===========================================
Example on plotting timeseries of ASOS data
===========================================

This example shows how to plot timeseries of ASOS data from
Chicago O'Hare airport.

.. GENERATED FROM PYTHON SOURCE LINES 10-24



.. image:: /source/auto_examples/images/sphx_glr_plot_asos_temp_001.png
    :alt: act_datastream temp on 20200204, act_datastream on 20200204
    :class: sphx-glr-single-img


.. rst-class:: sphx-glr-script-out

 Out:

 .. code-block:: none

    Downloading: ORD
    /Users/atheisen/Code/ACT/act/plotting/plot.py:82: UserWarning: Could not discern datastreamname and dict or tuple were not provided. Using defaultname of act_datastream!
      warnings.warn(("Could not discern datastream" +






|

.. code-block:: default

    import act
    import matplotlib.pyplot as plt

    from datetime import datetime
    time_window = [datetime(2020, 2, 4, 2, 0), datetime(2020, 2, 10, 10, 0)]
    station = "KORD"
    my_asoses = act.discovery.get_asos(time_window, station="ORD")

    my_disp = act.plotting.TimeSeriesDisplay(
        my_asoses['ORD'], subplot_shape=(2, ), figsize=(15, 10))
    my_disp.plot('temp', subplot_index=(0, ))
    my_disp.plot_barbs_from_u_v(u_field='u', v_field='v', subplot_index=(1, ))
    my_disp.axes[1].set_ylim([0, 2])
    plt.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 1 minutes  8.796 seconds)


.. _sphx_glr_download_source_auto_examples_plot_asos_temp.py:


.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-example



  .. container:: sphx-glr-download sphx-glr-download-python

     :download:`Download Python source code: plot_asos_temp.py <plot_asos_temp.py>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

     :download:`Download Jupyter notebook: plot_asos_temp.ipynb <plot_asos_temp.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
